//


#include "SPI.h"
#include "NRFLite.h"

const static uint8_t RADIO_ID = 1;             // ID dieses Funkteilnehmers
const static uint8_t DESTINATION_RADIO_ID = 0; // ID des Zielteilnehmers (Empfänger)
const static uint8_t PIN_RADIO_CE = 9;         // CE-Pin am Arduino
const static uint8_t PIN_RADIO_CSN = 10;       // CSN-Pin am Arduino

struct RadioPacket      // Datenarray zum Versenden per Funkmodul. 
{                       // Unterschiedliche Datentypen sind möglich. Max 32 Byte
    uint8_t abstand;    // Ermittelte Distanz in CM
    //uint32_t Optionale_variable;
};

NRFLite _radio;
RadioPacket _radioData;

const int trig = 3;     // Arduino-Pin für Sonarmodul TRIG-Anschluss
const int echo = 2;     // Arduino-Pin für Sonarmodul ECHO-Anschluss
long dauer;             // Variable für die vom Sonarmodul gemessene Echo-Zeit

void setup() {
Serial.begin(115200);   // Serielle Verbindung aktivieren (Datenrate = 115200 Bit pro Sekunde)
// Kann genutzt werden, um im "Seriellen Monitor" in der Arduino IDE über USB Statusmeldungen abzurufen.

// Initialisieren des Funkmoduls und einstellen der Bitrate und des Kanals  (250 kbit pro Sekunde, Kanal 0)
// Sender und Empfänger müssen gleich konfiguriert sein.
if (!_radio.init(RADIO_ID, PIN_RADIO_CE, PIN_RADIO_CSN, NRFLite::BITRATE250KBPS, 0))
    {
        Serial.print("Sender: ");
        Serial.println("Kommunikation mit Funkmodul läuft nicht.");
        Serial.print("Sender: ");
        Serial.println("Verbindungen zum NRF24-Modul überprüfen.");
        while (1); // Programmende bei Fehler
    }  
        
pinMode(trig, OUTPUT);  // Arduino-Pin für Sonarmodul TRIG-Anschluss als Ausgang
pinMode(echo, INPUT);   // Arduino-Pin für Sonarmodul ECHO-Anschlus als Eingang
}

void loop() {
// trig-Anschluss aktivieren
digitalWrite(trig, LOW);
delayMicroseconds(2);
// trig-Anschluss für 10 Mikrosekunden aktivieren
digitalWrite(trig, HIGH);
delayMicroseconds(10);
digitalWrite(trig, LOW);
// echo-Anschluss lesen, gibt die Reisezeit der Ultraschallwelle in Mikrosekunden zurück
dauer = pulseIn(echo, HIGH);


// Berechnung der Distanz aus dem gemessenen Echo-Zeitwert des Sonarmoduls. 
// Gemessene Dauer des Schallsignals (hin und zurück) in Mikrosekunden * Schallgeschwindigkeit 0,0034 cm / Mikrosekunde
// Ergibt: Abstand in CM
_radioData.abstand = (dauer * 0.034 / 2);

Serial.print("Sender: gemessener Abstand in cm: ");
Serial.print(_radioData.abstand);

if (_radio.send(DESTINATION_RADIO_ID, &_radioData, sizeof(_radioData))) // Sendevorgang
    {
        Serial.println("...erfolgreich gesendet");
    }
    else
    {
        Serial.println("...Fehler beim Senden");
    }

delay(10);
}
////////////////////////
